package jalview.api;

import jalview.datamodel.ColumnSelection;
import jalview.datamodel.SequenceI;
import jalview.schemes.ColourSchemeI;

/**
 * This interface should be implemented by complex file parser with the ability
 * to store linked data and complex view states in addition to Alignment data
 * 
 *
 */
public interface ComplexAlignFile
{
  /**
   * Determines if Sequence features should be shown
   * 
   * @return
   */
  public boolean isShowSeqFeatures();

  /**
   * Obtains the colour scheme from a complex file parser
   * 
   * @return
   */
  public ColourSchemeI getColourScheme();

  /**
   * Retrieves the Column selection/hidden column from a complex file parser
   * 
   * @return
   */
  public ColumnSelection getColumnSelection();

  /**
   * Retrieves hidden sequences from a complex file parser
   * 
   * @return
   */
  public SequenceI[] getHiddenSequences();

  /**
   * Retrieves displayed features from a complex file parser
   * 
   * @return
   */
  public FeaturesDisplayedI getDisplayedFeatures();
}
